Skip to contents

Class that created the general structure of all models introduced within this package.

Slots

d

Integer denoting the number of dimensions of the model

k

Integer denoting the number of independent variables

n

Integer denoting the number of parameters in the model

parameters

List containing the parameters relevant to a particular model instance

covariance

Numeric matrix denoting the residual covariance of the model

See also