This class contains the standard format for the dataset to be used within this project, ensuring a standardized approach for all computations.
Slots
YNumeric matrix of observations to be fitted, that is the dependent variables
XNumeric matrix of the stimuli that should be related to
Y, that is the independent variablesNInteger denoting the number of datapoints contained in
YandX. This value is automatically generated in the constructor of the dataset (seedataset).