Class for the exponential discounting model. Follows a similar structure to
the model-class.
Slots
dInteger denoting the number of dimensions of the model
kInteger denoting the number of independent variables
nInteger denoting the number of parameters
parametersList containing the parameters relevant to a particular model instance
covarianceNumeric matrix denoting the residual covariance of the model