Get bounds for the parameters in the covariance matrix
Arguments
- d
Integer denoting the dimensionality of the model.
- lower, upper
Numeric value containing the value of the lower and upper bounds for the covariance matrix.
- covariance
Character denoting the structure of the covariance matrix. Can either be
"symmetric"(symmetric around the diagonal) or"isotropic"(diagonal). Defaults to"symmetric".