Class that created the general structure of all models introduced within this package.
Slots
dInteger denoting the number of dimensions of the model
kInteger denoting the number of independent variables
nInteger denoting the number of parameters in the model
parametersList containing the parameters relevant to a particular model instance
covarianceNumeric matrix denoting the residual covariance of the model